@@ -357,12 +357,15 @@ class BatchProcessor:
     def get_job_counts(self):
         raw = self.db.get_job_counts()
         out = {}
+        totals = {}
         for row in raw:
             t = row.get("type")
             s = row.get("status")
             c = row.get("count")
+            totals[s] += count
             out[t] = out.get(t, {})
             out[t][s] = c
+        out["total"] = totals
         return out
 
     def get_status(self):
@@ -370,6 +373,9 @@ class BatchProcessor:
         status = {
             "status": self.db.get_status_counts(),
             "last": self.db.get_last_jobs(limit=20),
+            "last_failed": self.db.get_last_jobs(limit=20, status="failed"),
+            "last_pending": self.db.get_last_jobs(limit=20, status="pending"),
+            "last_in_progress": self.db.get_last_jobs(limit=20, status="in_progress"),
             "counts": self.get_job_counts()}
         # fmt: on
         return status
